package Acme::MadokaMagica::TvMembers::AkemiHomura;
use Mouse;
extends 'Acme::MadokaMagica::TvMembers';
use utf8;

no Mouse;

1;

__DATA__

@@ AkemiHomura
firstname: ほむら
lastname: 暁美
age: 14
birthday: 3/12
blood_type: A
cv: 斎藤千和
say: それには及ばないわ
witchename:Homulilly
color:purple
