package Acme::MadokaMagica::TvMembers::SakuraKyoko;
use Mouse;
extends 'Acme::MadokaMagica::TvMembers';
use utf8;

no Mouse;

1;

__DATA__

@@ SakuraKyoko
firstname: 杏子
lastname: 佐倉
age: 14
birthday: 6/8
blood_type: A
cv: 野中藍
say: 喰うかい?
witchename: Ophelia
color:Red
