package Acme::MadokaMagica::TvCharacters::KanameMadoka;
use Mouse;
extends 'Acme::MadokaMagica::TvCharacters';
use utf8;

no Mouse;

1;

__DATA__

@@ KanameMadoka
firstname: まどか
lastname: 鹿目
age: 14
birthday: 10/3
blood_type: A
cv: 悠木碧
say: ウェヒヒww
witchename:Kriemhild_Gretchen
color:Pink
